% makeContour.m
% This script calls ComputeEnergyMC to compute energy values over a grid of 
% (efr,log10(kd)) values defined in runDramPlusContours.m
% Prior probability information not included
%
% C. Lichten, University of Edinburgh, 2010
% http://swainlab.bio.ed.ac.uk/software.php

%% 1. Define grid
% Use limits from chain (random walk)
% Efr_lo= min([0.1 min(chain(:,1))]); Efr_hi= max([1 max(chain(:,1))]);
% logkd_lo= min([-7 min(chain(:,2))]); logkd_hi= max([2 max(chain(:,2))]);

% Or define custom limits:
Efr_lo= .01; Efr_hi= 1;
logkd_lo= -9.5; logkd_hi= -2.5; 

% Choose low- or high-resolution contour:
% Low-Res:
Efr= linspace(Efr_lo,Efr_hi,20); log10kd= linspace(logkd_lo,logkd_hi,50);
% High-Res:
% Efr= linspace(Efr_lo,Efr_hi,200); log10kd=
% linspace(logkd_lo,logkd_hi,500);

%% 2. Evaluate energy across grid
tic
enrgcon= zeros(length(Efr),length(log10kd));
sum_optE= enrgcon; printint= fix(length(Efr)/3);
for i= 1:length(Efr)
    clear ComputeEnergyMC % resets x0 for fminsearch  
    % b/c log10kd changes from max to min value at the end of its loop 
    % (It is saved as a persistent var in ComputeEnergyMC)
    for j= 1:length(log10kd)
        efrkd= [Efr(i) log10kd(j)];
        enrgcon(i,j)= ComputeEnergyMC(efrkd,params,data);
    end
    if i/printint == fix(i/printint) % info on every printint iteration
        fprintf('Contour is %2.0f%% done\n',fix(i/length(Efr)*100));
    end
end

enrgcon(enrgcon==Inf)= NaN;  
contourtime= toc;

fprintf('Energy contour completed in %2.0f seconds \n',contourtime);
